utils::globalVariables(
  c(
    ":=",
    "!!",
    "Parameter1",
    "Parameter2",
    "code",
    "code_names",
    "code_pipe",
    "corrs",
    "corrs_computed",
    "data",
    "decision",
    "description",
    "each",
    "filters",
    "group",
    "grp",
    "icc",
    "icc_per",
    "id",
    "key",
    "model",
    "model_fitted",
    "model_function",
    "model_messages",
    "model_meta",
    "model_parameters",
    "model_performance",
    "model_warnings",
    "models",
    "my_from",
    "my_to",
    "n",
    "n_retained",
    "new_order",
    "nodes",
    "parameter",
    "parameter_key",
    "parameter_keys",
    "postprocess",
    "preprocess",
    "r",
    "reliabilities",
    "reliabilities_computed",
    "specifications",
    "stat",
    "sum_var",
    "summary_stats",
    "summary_stats_computed",
    "term",
    "type",
    "v1",
    "v2",
    "value",
    "vcov",
    "subgroups",
    "coefficient",
    "ci",
    "ci_low",
    "ci_high",
    "std_coefficient",
    "additional_args",
    "model_args"
    )
)
